@@ -3,9 +3,9 @@ import sys
 from unittest import TestCase
 
 import jaseci.jac.tests.book_code as jtc
-from jaseci.actor.sentinel import Sentinel
-from jaseci.graph.graph import Graph
-from jaseci import JsOrc
+from jaseci.prim.sentinel import Sentinel
+from jaseci.prim.graph import Graph
+from jaseci.jsorc.jsorc import JsOrc
 from jaseci.utils.utils import TestCaseHelper
 
 
