@@ -1,7 +1,7 @@
 import os
 from unittest import TestCase
 
-from jaseci import JsOrc
+from jaseci.jsorc.jsorc import JsOrc
 from jaseci.utils.utils import TestCaseHelper
 
 
@@ -27,17 +27,21 @@ class CoreTest(TestCaseHelper, TestCase):
             return f.read()
 
 
-def jac_testcase(jac_file: str, test_name: str):
+def jac_testcase(jac_file: str, test_name: str, log_out: bool = False):
     """decorator for test cases"""
 
     def decorator(func):
         def wrapper(self):
+            if log_out:
+                self.logger_on()
             self.call(
                 self.mast,
                 ["sentinel_register", {"code": self.load_jac(jac_file)}],
             )
             ret = self.call(self.mast, ["walker_run", {"name": test_name}])
             func(self, ret)
+            if log_out:
+                self.logger_off()
 
         return wrapper
 
